VerticalLayout

Struct VerticalLayout 

pub struct VerticalLayout { /* private fields */ }
A Layout node that arranges it’s children vertically.

This layout’s main axis is the y-axis, and it’s cross axis is the x-axis.

Example

use cascada::{solve_layout, AxisAlignment, EmptyLayout, IntrinsicSize, Padding, Size, VerticalLayout};

let child = EmptyLayout::new()
    .intrinsic_size(IntrinsicSize::fixed(12.0,50.0));


let mut layout = VerticalLayout::new()
    .spacing(12)
    .padding(Padding::all(24.0))
    .add_children([child.clone(),child])
    .main_axis_alignment(AxisAlignment::Center);

solve_layout(&mut layout, Size::unit(500.0));

Algorithm

  • BoxSizing::Shrink: The minimum width is set to the sum of the minimum widths of all the children + spacing + horizontal padding.
  • BoxSizing::Fixed: The minimum width is set to the fixed width regardless of all other properties.

If the intrinsic height is BoxSizing::Shrink then the final height will be the sum of the all child node heights + vertical padding + spacing.

Implementations

Source

impl VerticalLayout

pub fn new() -> Self

Creates a new VerticalLayout.

pub fn set_id(self, id: GlobalId) -> Self

pub fn with_label(self, label: &str) -> Self

pub fn add_child(self, child: impl Layout + 'static) -> Self

Appends a Layout node to the list of children.

Example
use cascada::{EmptyLayout,VerticalLayout};

VerticalLayout::new()
    .add_child(EmptyLayout::default())
    .add_child(VerticalLayout::default());
pub fn add_children<I>(self, children: I) -> Self
where I: IntoIterator<Item: Layout + 'static>,

Add multiple child nodes to the list of children.

Example
use cascada::{VerticalLayout,EmptyLayout};

VerticalLayout::new()
    .add_children([
        EmptyLayout::new(),
        EmptyLayout::new(),
        EmptyLayout::new(),
    ]);
pub fn add_boxed_children<I>(self, children: I) -> Self
where I: IntoIterator<Item = Box<dyn Layout + 'static>>,

pub fn main_axis_alignment(self, main_axis_alignment: AxisAlignment) -> Self

Set the main axis alignment

pub fn cross_axis_alignment(self, cross_axis_alignment: AxisAlignment) -> Self

Set the cross axis alignment.

pub fn padding(self, padding: Padding) -> Self

Set this layout’s Padding.

pub fn spacing(self, spacing: u32) -> Self

Set this layout’s spacing.

pub fn main_axis_overflow(&self) -> bool

Returns true if a VerticalLayout’s children are overflowing its main-axis (y-axis).

pub fn cross_axis_overflow(&self) -> bool

Returns true if a VerticalLayout’s children are overflowing its cross-axis (x-axis).

pub fn max_width(self, width: f32) -> Self

Sets the maximum width of the layout node.

pub fn maximum_height(self, height: f32) -> Self

Sets the maximum height of the layout node.

pub fn min_width(self, width: f32) -> Self

Sets the minimum width of the layout node.

pub fn min_height(self, height: f32) -> Self

Sets the minimum height of the layout node.

pub fn intrinsic_size(self, intrinsic_size: IntrinsicSize) -> Self

Sets the intrinsic size of the layout node.